'''
This module is to surf to the main pages of Jw.og and to download publications from it.
'''

from browseJw import browse


class JwSurfer:
    '''
    This class contains methods to surf the main pages of Jw and to download publications from Jw.org and save to a Folder. 
    '''

    def showInfo():
        print("-------Usage-------")
        print("[-h] >> To navigate to the home page")
        print("[-n] >> To navigate to the news-room page")
        print("[-l] >> To navigate to the Library page")
        print("[-bt] >> To navigate to the Bible teachings page")
        print("[-a] >> To navigate to the about page")
        print("[quit] >> To quit the program")

    while True:
        showInfo()
        user_input = str(input())
        if user_input.lower() == "quit":
            break
        if user_input.lower() == "-h":
            browse(user_input)
        elif user_input.lower() == "-n":
            browse(user_input)
        elif user_input.lower() == "-l":
            browse(user_input)
        elif user_input.lower() == "-bt":
            browse(user_input)
        elif user_input.lower() == "-a":
            browse(user_input)
        else:
            print("input a valid Argument")
            print("Your input was ", user_input.lower())
            print("Please refer the usage for proper input")
            # showInfo()



import webbrowser

def browse(page):

    if page == "-h":
        webbrowser.open("https://www.jw.org/en/")
    elif page == "-a":
        webbrowser.open("https://www.jw.org/en/jehovahs-witnesses/")
    elif page == '-n':
        webbrowser.open("https://www.jw.org/en/news/jw/")
    elif page == "-bt":
        webbrowser.open("https://www.jw.org/en/bible-teachings/")
    elif page == "-l":
        webbrowser.open("https://www.jw.org/en/library/")
    else:
        print("Enter a valid input parameter.")